"use client";

import { SimpleGrid, Icon, useColorModeValue, Box, Text } from "@chakra-ui/react";
import MiniStatistics from "@/components/card/MiniStatistics";
import { MdGroup } from "react-icons/md";
import { TbUsersGroup } from "react-icons/tb";
import IconBox from "components/icons/IconBox";
import { IoBriefcaseSharp } from "react-icons/io5";
import { FaUsers } from "react-icons/fa6";
import { BsFillPeopleFill, BsPersonBadge } from "react-icons/bs";
import { useGeneral } from "@/contexts/GeneralContext";
import { setStorage } from "@/utils/navigation";
import { useRouter } from "next/navigation";
import { setCookie } from 'cookies-next';
import { ProjectInterface } from "@/types/project";
import { useSession } from "next-auth/react";

const ProjectsGrid = () => {
  const { newProjects, saveProjectId, projectId } = useGeneral();
  const router = useRouter()
  const boxBg = useColorModeValue("secondaryGray.300", "whiteAlpha.100");
  const brandColor = useColorModeValue("brand.500", "white");
  const { data: session, status, update } = useSession();

  const handleSetProject = async (value: string | number) => {
    setStorage('x-project-id', value?.toString())
    session.currentProjectId = value?.toString();
    await update({
      ...session,
      currentProjectId: value,
    });
    saveProjectId(value?.toString())
    router.push('/officer/dashboard')
  }



  return (
    <SimpleGrid columns={{ base: 1, md: 2, lg: 4, "2xl": 4 }} gap="20px" mb="20px">
      {projectId?.toString()}
      {newProjects?.map((project) => (
        <Box
          key={project?.id}
          display="flex" alignItems="center" justifyContent="space-between" bg="#fff" rounded="12px" padding={4} cursor="pointer"
          onClick={() => handleSetProject(project?.id)}
        >
          <Text fontSize={24} fontWeight={500}>{project?.name ?? ''}</Text>
          <Text fontSize={24} fontWeight={500}>{project?.id ?? ''}</Text>
        </Box>
      ))}
    </SimpleGrid>
  );
};

export default ProjectsGrid;
